
<!-- Well we could have implemented this in https://smarie.github.io/mkdocs-gallery/... -->

# Gallery

## 1D Histogram Comparisons

::cards:: cols=4

- title:
  content: Asymmetry comparison
  image: baseline/1d_comparison_asymmetry.png
  url: gallery/1d_comparison_asymmetry.md

- title:
  content: Difference comparison
  image: baseline/1d_comparison_difference.png
  url: gallery/1d_comparison_difference.md

- title:
  content: Efficiency comparison
  image: baseline/1d_comparison_efficiency.png
  url: gallery/1d_comparison_efficiency.md

- title:
  content: Only efficiency comparison
  image: baseline/1d_comparison_only_efficiency.png
  url: gallery/1d_comparison_only_efficiency.md

- title:
  content: Pull comparison
  image: baseline/1d_comparison_pull.png
  url: gallery/1d_comparison_pull.md

- title:
  content: Ratio comparison
  image: baseline/1d_comparison_ratio.png
  url: gallery/1d_comparison_ratio.md

- title:
  content: Relative difference comparison
  image: baseline/1d_comparison_relative_difference.png
  url: gallery/1d_comparison_relative_difference.md

- title:
  content: Split ratio comparison
  image: baseline/1d_comparison_split_ratio.png
  url: gallery/1d_comparison_split_ratio.md

::/cards::

## Model Comparisons

::cards:: cols=4

- title:
  content: Model all comparisons
  image: baseline/model_all_comparisons.png
  url: gallery/model_all_comparisons.md

- title:
  content: Model all comparisons no model uncertainty
  image: baseline/model_all_comparisons_no_model_unc.png
  url: gallery/model_all_comparisons_no_model_unc.md

- title:
  content: Model examples pull
  image: baseline/model_examples_pull.png
  url: gallery/model_examples_pull.md

- title:
  content: Model examples pull no model uncertainty
  image: baseline/model_examples_pull_no_model_unc.png
  url: gallery/model_examples_pull_no_model_unc.md

- title:
  content: Model examples stacked
  image: baseline/model_examples_stacked.png
  url: gallery/model_examples_stacked.md

- title:
  content: Model examples stacked unstacked
  image: baseline/model_examples_stacked_unstacked.png
  url: gallery/model_examples_stacked_unstacked.md

- title:
  content: Model examples unstacked
  image: baseline/model_examples_unstacked.png
  url: gallery/model_examples_unstacked.md

- title:
  content: Model with stacked and unstacked function components
  image: baseline/model_with_stacked_and_unstacked_function_components.png
  url: gallery/model_with_stacked_and_unstacked_function_components.md

- title:
  content: Model with stacked and unstacked histograms components
  image: baseline/model_with_stacked_and_unstacked_histograms_components.png
  url: gallery/model_with_stacked_and_unstacked_histograms_components.md

- title:
  content: Ratio data vs model with stacked and unstacked function components
  image: baseline/ratio_data_vs_model_with_stacked_and_unstacked_function_components.png
  url: gallery/ratio_data_vs_model_with_stacked_and_unstacked_function_components.md

::/cards::
